@@ -3,15 +3,17 @@ table2ascii - Library for converting 2D Python lists to fancy ASCII/Unicode tabl
 """
 
 from .alignment import Alignment
+from .merge import Merge
 from .preset_style import PresetStyle
 from .table_style import TableStyle
 from .table_to_ascii import table2ascii
 
-__version__ = "0.4.0"
+__version__ = "1.0.2"
 
 __all__ = [
-    "table2ascii",
     "Alignment",
-    "TableStyle",
+    "Merge",
     "PresetStyle",
+    "TableStyle",
+    "table2ascii",
 ]
